@@ -1,7 +1,5 @@
 import pytest
-from pytest import raises
 
-from vyper import compiler
 from vyper.exceptions import InvalidType, UnknownType
 
 fail_list = [
@@ -25,9 +23,8 @@ struct A:
 
 
 @pytest.mark.parametrize("bad_code", fail_list)
-def test_unknown_type_exception(bad_code):
-    with raises(UnknownType):
-        compiler.compile_code(bad_code)
+def test_unknown_type_exception(bad_code, get_contract, assert_compile_failed):
+    assert_compile_failed(lambda: get_contract(bad_code), UnknownType)
 
 
 invalid_list = [
@@ -68,10 +65,13 @@ x: int128[3.5]
     """
 b: HashMap[(int128, decimal), int128]
     """,
+    # Address literal must be checksummed
+    """
+a: constant(address) = 0x3cd751e6b0078be393132286c442345e5dc49699
+    """,
 ]
 
 
 @pytest.mark.parametrize("bad_code", invalid_list)
-def test_invalid_type_exception(bad_code):
-    with raises(InvalidType):
-        compiler.compile_code(bad_code)
+def test_invalid_type_exception(bad_code, get_contract, assert_compile_failed):
+    assert_compile_failed(lambda: get_contract(bad_code), InvalidType)
