@@ -1,3 +1,6 @@
+import pytest
+
+
 def test_continue1(get_contract_with_gas_estimation):
     code = """
 @external
@@ -53,3 +56,32 @@ def foo() -> int128:
 """
     c = get_contract_with_gas_estimation(code)
     assert c.foo() == 3
+
+
+fail_list = [
+    """
+@external
+def foo():
+    a: uint256 = 3
+    continue
+    """,
+    """
+@external
+def foo():
+    if True:
+        continue
+    """,
+    """
+@external
+def foo():
+    for i in [1, 2, 3]:
+        b: uint256 = i
+    if True:
+        continue
+    """,
+]
+
+
+@pytest.mark.parametrize("bad_code", fail_list)
+def test_block_fail(assert_compile_failed, get_contract_with_gas_estimation, bad_code):
+    assert_compile_failed(lambda: get_contract_with_gas_estimation(bad_code))
