@@ -12,11 +12,7 @@ def hardtest(arg1: Bytes[64], arg2: Bytes[64]) -> Bytes[128]:
     # Make sure underlying structe is correctly right padded
     classic_contract = c._classic_contract
     func = classic_contract.functions.hardtest(b"hello" * 5, b"hello" * 10)
-    tx = func.buildTransaction(
-        {
-            "gasPrice": 0,
-        }
-    )
+    tx = func.buildTransaction({"gasPrice": 0})
     del tx["chainId"]
     del tx["gasPrice"]
 
