@@ -23,8 +23,7 @@ def test():
     {constant}: int128 = 31337
     """
     assert_compile_failed(
-        lambda: get_contract(code),
-        (SyntaxException, StructureException, NamespaceCollision),
+        lambda: get_contract(code), (SyntaxException, StructureException, NamespaceCollision)
     )
 
 
@@ -32,8 +31,7 @@ def test():
 def test_reserved_keywords_storage(constant, get_contract, assert_compile_failed):
     code = f"{constant}: int128"
     assert_compile_failed(
-        lambda: get_contract(code),
-        (SyntaxException, StructureException, NamespaceCollision),
+        lambda: get_contract(code), (SyntaxException, StructureException, NamespaceCollision)
     )
 
 
@@ -45,8 +43,7 @@ def test({constant}: int128):
     pass
     """
     assert_compile_failed(
-        lambda: get_contract(code),
-        (SyntaxException, StructureException, NamespaceCollision),
+        lambda: get_contract(code), (SyntaxException, StructureException, NamespaceCollision)
     )
 
 
@@ -61,6 +58,5 @@ def {constant}(var: int128):
     pass
     """
     assert_compile_failed(
-        lambda: get_contract(code),
-        (SyntaxException, StructureException, NamespaceCollision),
+        lambda: get_contract(code), (SyntaxException, StructureException, NamespaceCollision)
     )
