@@ -75,6 +75,7 @@ from vyper.semantics.types import (
 from vyper.semantics.types.abstract import (
     ArrayValueAbstractType,
     BytesAbstractType,
+    FixedAbstractType,
     IntegerAbstractType,
     NumericAbstractType,
     SignedIntegerAbstractType,
@@ -92,6 +93,7 @@ from vyper.semantics.types.value.array_value import (
 from vyper.semantics.types.value.bytes_fixed import Bytes4Definition  # type: ignore
 from vyper.semantics.types.value.bytes_fixed import Bytes32Definition
 from vyper.semantics.types.value.numeric import Int256Definition  # type: ignore
+from vyper.semantics.types.value.numeric import Uint8Definition  # type: ignore
 from vyper.semantics.types.value.numeric import Uint256Definition  # type: ignore
 from vyper.semantics.types.value.numeric import DecimalDefinition
 from vyper.semantics.validation.utils import (
@@ -121,6 +123,35 @@ SHA256_BASE_GAS = 60
 SHA256_PER_WORD_GAS = 12
 
 
+class FoldedFunction(BuiltinFunction):
+    # Base class for nodes which should always be folded
+
+    # Since foldable builtin functions are not folded before semantics validation,
+    # this flag is used for `check_kwargable` in semantics validation.
+    _kwargable = True
+
+
+class TypenameFoldedFunction(FoldedFunction):
+    # Base class for builtin functions that:
+    # (1) take a typename as the only argument; and
+    # (2) should always be folded.
+
+    # "TYPE_DEFINITION" is a placeholder value for a type definition string, and
+    # will be replaced by a `TypeTypeDefinition` object in `infer_arg_types`.
+    _inputs = [("typename", "TYPE_DEFINITION")]
+
+    def fetch_call_return(self, node):
+        type_ = self.infer_arg_types(node)[0].typedef
+        return type_
+
+    def infer_arg_types(self, node):
+        validate_call_args(node, 1)
+        input_typedef = TypeTypeDefinition(
+            get_type_from_annotation(node.args[0], DataLocation.MEMORY)
+        )
+        return [input_typedef]
+
+
 class Floor(BuiltinFunction):
 
     _id = "floor"
@@ -701,7 +732,7 @@ class Sha256(BuiltinFunction):
         )
 
 
-class MethodID(BuiltinFunction):
+class MethodID(FoldedFunction):
 
     _id = "method_id"
 
@@ -714,36 +745,32 @@ class MethodID(BuiltinFunction):
         if " " in args[0].value:
             raise InvalidLiteral("Invalid function signature - no spaces allowed.")
 
-        if node.keywords:
-            return_type = get_type_from_annotation(node.keywords[0].value, DataLocation.UNSET)
-            if isinstance(return_type, Bytes4Definition):
-                is_bytes4 = True
-            elif isinstance(return_type, BytesArrayDefinition) and return_type.length == 4:
-                is_bytes4 = False
-            else:
-                raise ArgumentException("output_type must be Bytes[4] or bytes4", node.keywords[0])
-        else:
-            # If `output_type` is not given, default to `Bytes[4]`
-            is_bytes4 = False
-
+        return_type = self.infer_kwarg_types(node)
         value = abi_method_id(args[0].value)
 
-        if is_bytes4:
+        if isinstance(return_type, Bytes4Definition):
             return vy_ast.Hex.from_node(node, value=hex(value))
         else:
             return vy_ast.Bytes.from_node(node, value=value.to_bytes(4, "big"))
 
     def fetch_call_return(self, node):
-        raise CompilerPanic("method_id should always be folded")
+        validate_call_args(node, 1, ["output_type"])
 
-    def infer_arg_types(self, node):
-        raise CompilerPanic("method_id should always be folded")
+        type_ = self.infer_kwarg_types(node)
+        return type_
 
     def infer_kwarg_types(self, node):
-        raise CompilerPanic("method_id should always be folded")
+        if node.keywords:
+            return_type = get_type_from_annotation(node.keywords[0].value, DataLocation.UNSET)
+            if isinstance(return_type, Bytes4Definition):
+                return Bytes4Definition()
+            elif isinstance(return_type, BytesArrayDefinition) and return_type.length == 4:
+                return BytesArrayDefinition(4)
+            else:
+                raise ArgumentException("output_type must be Bytes[4] or bytes4", node.keywords[0])
 
-    def build_IR(self, *args, **kwargs):
-        raise CompilerPanic("method_id should always be folded")
+        # If `output_type` is not given, default to `Bytes[4]`
+        return BytesArrayDefinition(4)
 
 
 class ECRecover(BuiltinFunction):
@@ -751,12 +778,17 @@ class ECRecover(BuiltinFunction):
     _id = "ecrecover"
     _inputs = [
         ("hash", Bytes32Definition()),
-        ("v", Uint256Definition()),
-        ("r", Uint256Definition()),
-        ("s", Uint256Definition()),
+        ("v", (Uint256Definition(), Uint8Definition())),
+        ("r", (Uint256Definition(), Bytes32Definition())),
+        ("s", (Uint256Definition(), Bytes32Definition())),
     ]
     _return_type = AddressDefinition()
 
+    def infer_arg_types(self, node):
+        self._validate_arg_types(node)
+        v_t, r_t, s_t = [get_possible_types_from_node(arg).pop() for arg in node.args[1:]]
+        return [Bytes32Definition(), v_t, r_t, s_t]
+
     @process_inputs
     def build_IR(self, expr, args, kwargs, context):
         placeholder_node = IRnode.from_list(
@@ -872,7 +904,7 @@ class Extract32(BuiltinFunction):
     _inputs = [("b", BytesArrayPrimitive()), ("start", UnsignedIntegerAbstractType())]
     # "TYPE_DEFINITION" is a placeholder value for a type definition string, and
     # will be replaced by a `TypeTypeDefinition` object in `infer_kwarg_types`
-    # (note that it is ignored in validate_args)
+    # (note that it is ignored in `_validate_arg_types`)
     _kwargs = {"output_type": KwargSettings("TYPE_DEFINITION", "bytes32")}
     _return_type = None
 
@@ -2141,6 +2173,7 @@ class Sqrt(BuiltinFunction):
         from vyper.builtin_functions.utils import generate_inline_function
 
         arg = args[0]
+        # TODO: reify decimal and integer sqrt paths (see isqrt)
         sqrt_code = """
 assert x >= 0.0
 z: decimal = 0.0
@@ -2185,28 +2218,60 @@ else:
         )
 
 
-class Empty(BuiltinFunction):
+class ISqrt(BuiltinFunction):
+
+    _id = "isqrt"
+    _inputs = [("d", Uint256Definition())]
+    _return_type = Uint256Definition()
+
+    @process_inputs
+    def build_IR(self, expr, args, kwargs, context):
+        # calculate isqrt using the babylonian method
+
+        y, z = "y", "z"
+        arg = args[0]
+        with arg.cache_when_complex("x") as (b1, x):
+            ret = [
+                "seq",
+                [
+                    "if",
+                    ["ge", y, 2 ** (128 + 8)],
+                    ["seq", ["set", y, shr(128, y)], ["set", z, shl(64, z)]],
+                ],
+                [
+                    "if",
+                    ["ge", y, 2 ** (64 + 8)],
+                    ["seq", ["set", y, shr(64, y)], ["set", z, shl(32, z)]],
+                ],
+                [
+                    "if",
+                    ["ge", y, 2 ** (32 + 8)],
+                    ["seq", ["set", y, shr(32, y)], ["set", z, shl(16, z)]],
+                ],
+                [
+                    "if",
+                    ["ge", y, 2 ** (16 + 8)],
+                    ["seq", ["set", y, shr(16, y)], ["set", z, shl(8, z)]],
+                ],
+            ]
+            ret.append(["set", z, ["div", ["mul", z, ["add", y, 2 ** 16]], 2 ** 18]])
+
+            for _ in range(7):
+                ret.append(["set", z, ["div", ["add", ["div", x, z], z], 2]])
+
+            # note: If ``x+1`` is a perfect square, then the Babylonian
+            # algorithm oscillates between floor(sqrt(x)) and ceil(sqrt(x)) in
+            # consecutive iterations. return the floor value always.
+
+            ret.append(["with", "t", ["div", x, z], ["select", ["lt", z, "t"], z, "t"]])
+
+            ret = ["with", y, x, ["with", z, 181, ret]]
+            return b1.resolve(IRnode.from_list(ret, typ=BaseType("uint256")))
+
+
+class Empty(TypenameFoldedFunction):
 
     _id = "empty"
-    # "TYPE_DEFINITION" is a placeholder value for a type definition string, and
-    # will be replaced by a `TypeTypeDefinition` object in `infer_arg_types`
-    # (note that it is ignored in `validate_args`)
-    _inputs = [("typename", "TYPE_DEFINITION")]
-
-    # Since `empty` is not folded before semantics validation, this flag is used
-    # for `check_kwargable` in semantics validation.
-    _kwargable = True
-
-    def fetch_call_return(self, node):
-        type_ = self.infer_arg_types(node)[0].typedef
-        return type_
-
-    def infer_arg_types(self, node):
-        validate_call_args(node, 1)
-        input_typedef = TypeTypeDefinition(
-            get_type_from_annotation(node.args[0], DataLocation.MEMORY)
-        )
-        return [input_typedef]
 
     @process_inputs
     def build_IR(self, expr, args, kwargs, context):
@@ -2520,9 +2585,7 @@ class ABIDecode(BuiltinFunction):
             )
 
 
-class _MinMaxValue(BuiltinFunction):
-    _inputs = [("typename", "TYPE_DEFINITION")]
-
+class _MinMaxValue(TypenameFoldedFunction):
     def evaluate(self, node):
         self._validate_arg_types(node)
         input_type = get_type_from_annotation(node.args[0], DataLocation.UNSET)
@@ -2538,19 +2601,6 @@ class _MinMaxValue(BuiltinFunction):
             val = self._eval_int(input_type)
             return vy_ast.Int.from_node(node, value=val)
 
-    def fetch_call_return(self, node):  # pragma: no cover
-        raise CompilerPanic(f"{self._id} should always be folded")
-
-    def infer_arg_types(self, node):  # pragma: no cover
-        raise CompilerPanic(f"{self._id} should always be folded")
-
-    def infer_kwarg_types(self, node):  # pragma: no cover
-        raise CompilerPanic(f"{self._id} should always be folded")
-
-    # TODO we may want to provide this as the default impl on the base class
-    def build_IR(self, *args, **kwargs):  # pragma: no cover
-        raise CompilerPanic(f"{self._id} should always be folded")
-
 
 class MinValue(_MinMaxValue):
     _id = "min_value"
@@ -2576,6 +2626,25 @@ class MaxValue(_MinMaxValue):
         return typinfo.decimal_bounds[1]
 
 
+class Epsilon(TypenameFoldedFunction):
+    _id = "epsilon"
+
+    def evaluate(self, node):
+        self._validate_arg_types(node)
+        input_type = get_type_from_annotation(node.args[0], DataLocation.UNSET)
+
+        if not isinstance(input_type, FixedAbstractType):
+            raise InvalidType(f"Expected decimal type but got {input_type} instead", node)
+
+        # this check seems redundant, but sets a pattern to be followed
+        # when new decimal types are created
+        if isinstance(input_type, DecimalDefinition):
+            typinfo = parse_decimal_info(str(input_type))
+            return vy_ast.Decimal.from_node(node, value=typinfo.epsilon)
+
+        raise CompilerPanic("unreachable")  # pragma: notest
+
+
 DISPATCH_TABLE = {
     "_abi_encode": ABIEncode(),
     "_abi_decode": ABIDecode(),
@@ -2607,6 +2676,7 @@ DISPATCH_TABLE = {
     "unsafe_div": UnsafeDiv(),
     "pow_mod256": PowMod256(),
     "uint2str": Uint2Str(),
+    "isqrt": ISqrt(),
     "sqrt": Sqrt(),
     "shift": Shift(),
     "create_minimal_proxy_to": CreateMinimalProxyTo(),
@@ -2619,6 +2689,7 @@ DISPATCH_TABLE = {
     "abs": Abs(),
     "min_value": MinValue(),
     "max_value": MaxValue(),
+    "epsilon": Epsilon(),
 }
 
 STMT_DISPATCH_TABLE = {
