@@ -5,7 +5,7 @@ import json
 import sys
 import warnings
 from pathlib import Path
-from typing import Callable, Dict, Tuple, Union
+from typing import Any, Callable, Dict, Hashable, List, Tuple, Union
 
 import vyper
 from vyper.cli.utils import extract_file_interface_imports, get_interface_file_path
@@ -48,9 +48,7 @@ def _parse_args(argv):
         nargs="?",
     )
     parser.add_argument(
-        "--version",
-        action="version",
-        version=f"{vyper.__version__}+commit.{vyper.__commit__}",
+        "--version", action="version", version=f"{vyper.__version__}+commit.{vyper.__commit__}"
     )
     parser.add_argument(
         "-o",
@@ -113,10 +111,7 @@ def exc_handler_to_dict(file_path: Union[str, None], exception: Exception, compo
     }
     if hasattr(exception, "message"):
         err_dict.update(
-            {
-                "message": exception.message,  # type: ignore
-                "formattedMessage": str(exception),
-            }
+            {"message": exception.message, "formattedMessage": str(exception)}  # type: ignore
         )
     if file_path is not None:
         err_dict["sourceLocation"] = {"file": file_path}
@@ -128,20 +123,23 @@ def exc_handler_to_dict(file_path: Union[str, None], exception: Exception, compo
                 }
             )
 
-    output_json = {
-        "compiler": f"vyper-{vyper.__version__}",
-        "errors": [err_dict],
-    }
+    output_json = {"compiler": f"vyper-{vyper.__version__}", "errors": [err_dict]}
     return output_json
 
 
 def _standardize_path(path_str: str) -> str:
-    root_path = Path("/__vyper").resolve()
-    path = root_path.joinpath(path_str.lstrip("/")).resolve()
     try:
-        path = path.relative_to(root_path)
+        path = Path(path_str)
+
+        if path.is_absolute():
+            path = path.resolve()
+        else:
+            pwd = Path(".").resolve()
+            path = path.resolve().relative_to(pwd)
+
     except ValueError:
         raise JSONError(f"{path_str} - path exists outside base folder")
+
     return path.as_posix()
 
 
@@ -390,11 +388,7 @@ def compile_from_input_dict(
 
 
 def format_to_output_dict(compiler_data: Dict) -> Dict:
-    output_dict: Dict = {
-        "compiler": f"vyper-{vyper.__version__}",
-        "contracts": {},
-        "sources": {},
-    }
+    output_dict: Dict = {"compiler": f"vyper-{vyper.__version__}", "contracts": {}, "sources": {}}
     for id_, (path, data) in enumerate(compiler_data.items()):
 
         output_dict["sources"][path] = {"id": id_}
@@ -435,6 +429,21 @@ def format_to_output_dict(compiler_data: Dict) -> Dict:
     return output_dict
 
 
+# https://stackoverflow.com/a/49518779
+def _raise_on_duplicate_keys(ordered_pairs: List[Tuple[Hashable, Any]]) -> Dict:
+    """
+    Raise JSONError if a duplicate key exists in provided ordered list
+    of pairs, otherwise return a dict.
+    """
+    dict_out = {}
+    for key, val in ordered_pairs:
+        if key in dict_out:
+            raise JSONError(f"Duplicate key: {key}")
+        else:
+            dict_out[key] = val
+    return dict_out
+
+
 def compile_json(
     input_json: Union[Dict, str],
     exc_handler: Callable = exc_handler_raises,
@@ -444,7 +453,9 @@ def compile_json(
     try:
         if isinstance(input_json, str):
             try:
-                input_dict: Dict = json.loads(input_json)
+                input_dict: Dict = json.loads(
+                    input_json, object_pairs_hook=_raise_on_duplicate_keys
+                )
             except json.decoder.JSONDecodeError as exc:
                 new_exc = JSONError(str(exc), exc.lineno, exc.colno)
                 return exc_handler(json_path, new_exc, "json")
