@@ -1,4 +1,4 @@
-from typing import Optional, Tuple, Union
+from typing import Any, Dict, Optional, Tuple, Union
 
 from vyper import ast as vy_ast
 from vyper.abi_types import ABI_DynamicArray, ABI_StaticArray, ABI_Tuple, ABIType
@@ -12,7 +12,6 @@ from vyper.semantics.types.bases import (
     IndexableTypeDefinition,
     MemberTypeDefinition,
 )
-from vyper.semantics.types.value.array_value import BytesArrayDefinition, StringDefinition
 from vyper.semantics.types.value.numeric import Uint256Definition  # type: ignore
 
 
@@ -56,6 +55,19 @@ class _SequenceDefinition(IndexableTypeDefinition):
         new_args, return_type = self.value_type.get_signature()
         return (Uint256Definition(),) + new_args, return_type
 
+    def get_index_type(self) -> BaseTypeDefinition:
+        # override the default behaviour to return `Uint256Definition` for
+        # type annotation
+        return Uint256Definition()
+
+
+# override value at `k` with `val`, but inserting it before other keys
+# for formatting reasons. besides insertion order, equivalent to
+# `{k: val, **xs}`
+def _set_first_key(xs: Dict[str, Any], k: str, val: Any) -> dict:
+    xs.pop(k, None)
+    return {k: val, **xs}
+
 
 # TODO rename me to StaticArrayDefinition?
 class ArrayDefinition(_SequenceDefinition):
@@ -92,6 +104,12 @@ class ArrayDefinition(_SequenceDefinition):
     def abi_type(self) -> ABIType:
         return ABI_StaticArray(self.value_type.abi_type, self.length)
 
+    def to_abi_dict(self, name: str = "") -> Dict[str, Any]:
+        ret = self.value_type.to_abi_dict()
+        # modify the child name in place
+        ret["type"] += f"[{self.length}]"
+        return _set_first_key(ret, "name", name)
+
     @property
     def is_dynamic_size(self):
         return self.value_type.is_dynamic_size
@@ -155,6 +173,12 @@ class DynamicArrayDefinition(_SequenceDefinition, MemberTypeDefinition):
     def abi_type(self) -> ABIType:
         return ABI_DynamicArray(self.value_type.abi_type, self.length)
 
+    def to_abi_dict(self, name: str = "") -> Dict[str, Any]:
+        ret = self.value_type.to_abi_dict()
+        # modify the child name in place.
+        ret["type"] += "[]"
+        return _set_first_key(ret, "name", name)
+
     @property
     def is_dynamic_size(self):
         return True
@@ -194,6 +218,7 @@ class DynamicArrayPrimitive(BasePrimitive):
     _id = "DynArray"
     _type = DynamicArrayDefinition
     _valid_literal = (vy_ast.List,)
+    _as_array = True
 
     @classmethod
     def from_annotation(
@@ -223,17 +248,9 @@ class DynamicArrayPrimitive(BasePrimitive):
             node.slice.value.elements[0], location, is_constant, is_public, is_immutable
         )
 
-        if isinstance(value_type, (BytesArrayDefinition, StringDefinition)):
-            raise StructureException(f"{value_type._id} arrays are not supported", node)
-
         max_length = node.slice.value.elements[1].value
         return DynamicArrayDefinition(
-            value_type,
-            max_length,
-            location,
-            is_constant,
-            is_public,
-            is_immutable,
+            value_type, max_length, location, is_constant, is_public, is_immutable
         )
 
 
@@ -272,6 +289,10 @@ class TupleDefinition(_SequenceDefinition):
     def abi_type(self) -> ABIType:
         return ABI_Tuple([t.abi_type for t in self._member_types])
 
+    def to_abi_dict(self, name: str = "") -> dict:
+        components = [t.to_abi_dict() for t in self._member_types]
+        return {"name": name, "type": "tuple", "components": components}
+
     @property
     def size_in_bytes(self):
         return sum(i.size_in_bytes for i in self.value_type)
