@@ -1,6 +1,7 @@
 from typing import Type
 
 from vyper import ast as vy_ast
+from vyper.abi_types import ABI_Bytes, ABI_String, ABIType
 from vyper.exceptions import CompilerPanic, StructureException, UnexpectedValue
 from vyper.semantics import validation
 from vyper.utils import ceil32
@@ -64,10 +65,6 @@ class _ArrayValueDefinition(ValueTypeDefinition):
 
         return 32 + ceil32(self.length)
 
-    @property
-    def canonical_type(self) -> str:
-        return self._id.lower()
-
     def set_length(self, length):
         """
         Sets the exact length of the type.
@@ -97,6 +94,8 @@ class _ArrayValueDefinition(ValueTypeDefinition):
         if not super().compare_type(other):
             return False
 
+        # CMC 2022-03-18 TODO this method should be refactored so it does not have side effects
+
         # when comparing two literals, both now have an equal min-length
         if not self._length and not other._length:
             min_length = max(self._min_length, other._min_length)
@@ -150,10 +149,18 @@ class _ArrayValuePrimitive(BasePrimitive):
 class BytesArrayDefinition(BytesAbstractType, ArrayValueAbstractType, _ArrayValueDefinition):
     _id = "Bytes"
 
+    @property
+    def abi_type(self) -> ABIType:
+        return ABI_Bytes(self.length)
+
 
 class StringDefinition(ArrayValueAbstractType, _ArrayValueDefinition):
     _id = "String"
 
+    @property
+    def abi_type(self) -> ABIType:
+        return ABI_String(self.length)
+
 
 class BytesArrayPrimitive(_ArrayValuePrimitive):
     _id = "Bytes"
