@@ -179,7 +179,8 @@ def set_storage_slots(vyper_module: vy_ast.Module) -> StorageLayout:
 
     for node in vyper_module.get_children(vy_ast.VariableDecl):
 
-        if node.get("annotation.func.id") == "immutable":
+        # skip non-storage variables
+        if node.is_constant or node.is_immutable:
             continue
 
         type_ = node.target._metadata["type"]
@@ -210,9 +211,7 @@ def set_code_offsets(vyper_module: vy_ast.Module) -> Dict:
 
     ret = {}
     offset = 0
-    for node in vyper_module.get_children(
-        vy_ast.VariableDecl, filters={"annotation.func.id": "immutable"}
-    ):
+    for node in vyper_module.get_children(vy_ast.VariableDecl, filters={"is_immutable": True}):
         type_ = node._metadata["type"]
         type_.set_position(CodeOffset(offset))
 
