@@ -29,6 +29,7 @@ from vyper.semantics.types.function import (
     MemberFunctionDefinition,
     StateMutability,
 )
+from vyper.semantics.types.indexable.mapping import MappingDefinition
 from vyper.semantics.types.indexable.sequence import (
     ArrayDefinition,
     DynamicArrayDefinition,
@@ -87,7 +88,7 @@ def check_for_terminus(node_list: list) -> bool:
     return False
 
 
-def _check_iterator_assign(
+def _check_iterator_modification(
     target_node: vy_ast.VyperNode, search_node: vy_ast.VyperNode
 ) -> Optional[vy_ast.VyperNode]:
     similar_nodes = [
@@ -99,9 +100,21 @@ def _check_iterator_assign(
     for node in similar_nodes:
         # raise if the node is the target of an assignment statement
         assign_node = node.get_ancestor((vy_ast.Assign, vy_ast.AugAssign))
+        # note the use of get_descendants() blocks statements like
+        # self.my_array[i] = x
         if assign_node and node in assign_node.target.get_descendants(include_self=True):
             return node
 
+        attr_node = node.get_ancestor(vy_ast.Attribute)
+        # note the use of get_descendants() blocks statements like
+        # self.my_array[i].append(x)
+        if (
+            attr_node is not None
+            and node in attr_node.value.get_descendants(include_self=True)
+            and attr_node.attr in ("append", "pop", "extend")
+        ):
+            return node
+
     return None
 
 
@@ -128,36 +141,29 @@ def _validate_address_code_attribute(node: vy_ast.Attribute) -> None:
             if ok_func and ok_args:
                 return
         raise StructureException(
-            "(address).code is only allowed inside of a slice function with a constant length",
-            node,
+            "(address).code is only allowed inside of a slice function with a constant length", node
         )
 
 
 def _validate_msg_data_attribute(node: vy_ast.Attribute) -> None:
     if isinstance(node.value, vy_ast.Name) and node.value.id == "msg" and node.attr == "data":
         parent = node.get_ancestor()
-        if not isinstance(parent, vy_ast.Call) or parent.get("func.id") not in ("slice", "len"):
+        allowed_builtins = ("slice", "len", "raw_call")
+        if not isinstance(parent, vy_ast.Call) or parent.get("func.id") not in allowed_builtins:
             raise StructureException(
-                "msg.data is only allowed inside of the slice or len functions",
-                node,
+                "msg.data is only allowed inside of the slice or len functions", node
             )
         if parent.get("func.id") == "slice":
             ok_args = len(parent.args) == 3 and isinstance(parent.args[2], vy_ast.Int)
             if not ok_args:
                 raise StructureException(
-                    "slice(msg.data) must use a compile-time constant for length argument",
-                    parent,
+                    "slice(msg.data) must use a compile-time constant for length argument", parent
                 )
 
 
 class FunctionNodeVisitor(VyperNodeVisitorBase):
 
-    ignored_types = (
-        vy_ast.Break,
-        vy_ast.Constant,
-        vy_ast.Continue,
-        vy_ast.Pass,
-    )
+    ignored_types = (vy_ast.Break, vy_ast.Constant, vy_ast.Pass)
     scope_name = "function"
 
     def __init__(
@@ -171,6 +177,14 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
         self.expr_visitor = _LocalExpressionVisitor()
         namespace.update(self.func.arguments)
 
+        for node in fn_node.body:
+            self.visit(node)
+        if self.func.return_type:
+            if not check_for_terminus(fn_node.body):
+                raise FunctionDeclarationException(
+                    f"Missing or unmatched return statements in function '{fn_node.name}'", fn_node
+                )
+
         if self.func.mutability == StateMutability.PURE:
             node_list = fn_node.get_descendants(
                 vy_ast.Attribute,
@@ -180,7 +194,19 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
                     )
                 },
             )
-            if node_list:
+
+            # Add references to `self` as standalone address
+            self_references = fn_node.get_descendants(vy_ast.Name, {"id": "self"})
+            standalone_self = [
+                n for n in self_references if not isinstance(n.get_ancestor(), vy_ast.Attribute)
+            ]
+            node_list.extend(standalone_self)  # type: ignore
+
+            for node in node_list:
+                t = node._metadata.get("type")
+                if isinstance(t, ContractFunction) and t.mutability == StateMutability.PURE:
+                    # allowed
+                    continue
                 raise StateAccessViolation(
                     "not allowed to query contract or environment variables in pure functions",
                     node_list[0],
@@ -194,15 +220,6 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
                     "msg.value is not allowed in non-payable functions", node_list[0]
                 )
 
-        for node in fn_node.body:
-            self.visit(node)
-        if self.func.return_type:
-            if not check_for_terminus(fn_node.body):
-                raise FunctionDeclarationException(
-                    f"Missing or unmatched return statements in function '{fn_node.name}'",
-                    fn_node,
-                )
-
     def visit(self, node):
         super().visit(node)
         self.annotation_visitor.visit(node)
@@ -231,11 +248,16 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
             raise StructureException("Right-hand side of assignment cannot be a tuple", node.value)
 
         target = get_exact_type_from_node(node.target)
+        if isinstance(target, MappingDefinition):
+            raise StructureException(
+                "Left-hand side of assignment cannot be a HashMap without a key", node
+            )
 
         validate_expected_type(node.value, target)
         target.validate_modification(node, self.func.mutability)
 
         self.expr_visitor.visit(node.value)
+        self.expr_visitor.visit(node.target)
 
     def visit_AugAssign(self, node):
         if isinstance(node.value, vy_ast.Tuple):
@@ -264,6 +286,11 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
             raise InvalidType("Assertion test value must be a boolean", node.test)
         self.expr_visitor.visit(node.test)
 
+    def visit_Continue(self, node):
+        for_node = node.get_ancestor(vy_ast.For)
+        if for_node is None:
+            raise StructureException("`continue` must be enclosed in a `for` loop", node)
+
     def visit_Return(self, node):
         values = node.value
         if values is None:
@@ -329,8 +356,7 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
                         args[1].op, vy_ast.Add
                     ):
                         raise StructureException(
-                            "Second element must be the first element plus a literal value",
-                            args[0],
+                            "Second element must be the first element plus a literal value", args[0]
                         )
                     if not vy_ast.compare_nodes(args[0], args[1].left):
                         raise StructureException(
@@ -365,18 +391,25 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
 
         if isinstance(node.iter, (vy_ast.Name, vy_ast.Attribute)):
             # check for references to the iterated value within the body of the loop
-            assign = _check_iterator_assign(node.iter, node)
+            assign = _check_iterator_modification(node.iter, node)
             if assign:
                 raise ImmutableViolation("Cannot modify array during iteration", assign)
 
-        if node.iter.get("value.id") == "self":
+        # Check if `iter` is a storage variable. get_descendants` is used to check for
+        # nested `self` (e.g. structs)
+        iter_is_storage_var = (
+            isinstance(node.iter, vy_ast.Attribute)
+            and len(node.iter.get_descendants(vy_ast.Name, {"id": "self"})) > 0
+        )
+
+        if iter_is_storage_var:
             # check if iterated value may be modified by function calls inside the loop
             iter_name = node.iter.attr
             for call_node in node.get_descendants(vy_ast.Call, {"func.value.id": "self"}):
                 fn_name = call_node.func.attr
 
                 fn_node = self.vyper_module.get_children(vy_ast.FunctionDef, {"name": fn_name})[0]
-                if _check_iterator_assign(node.iter, fn_node):
+                if _check_iterator_modification(node.iter, fn_node):
                     # check for direct modification
                     raise ImmutableViolation(
                         f"Cannot call '{fn_name}' inside for loop, it potentially "
@@ -387,7 +420,7 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
                 for name in self.namespace["self"].members[fn_name].recursive_calls:
                     # check for indirect modification
                     fn_node = self.vyper_module.get_children(vy_ast.FunctionDef, {"name": name})[0]
-                    if _check_iterator_assign(node.iter, fn_node):
+                    if _check_iterator_modification(node.iter, fn_node):
                         raise ImmutableViolation(
                             f"Cannot call '{fn_name}' inside for loop, it may call to '{name}' "
                             f"which potentially modifies iterated storage variable '{iter_name}'",
@@ -454,9 +487,12 @@ class FunctionNodeVisitor(VyperNodeVisitorBase):
                     node,
                 )
 
-            if self.func.mutability == StateMutability.PURE:
+            if (
+                self.func.mutability == StateMutability.PURE
+                and fn_type.mutability != StateMutability.PURE
+            ):
                 raise StateAccessViolation(
-                    f"Cannot call any function from a {self.func.mutability.value} function", node
+                    "Cannot call non-pure function from a pure function", node
                 )
 
         if isinstance(fn_type, MemberFunctionDefinition) and fn_type.is_modifying:
